package com.clustercontrol.monitor.bean;

/**
 * 
 * ステータス情報を保持するDTO。<BR>
 * com.clustercontrol.monitor.ejb.entity.StatusInfoDataを継承し、<BR>
 * ファシリティパスを保持できるように拡張しています。<BR>
 * 
 * @see com.clustercontrol.monitor.ejb.entity.StatusInfoData 
 * 
 * @author kozakaik
 *
 */
public class StatusInfoData extends
		com.clustercontrol.notify.monitor.ejb.entity.StatusInfoData {
	
	public String facilityPath;
	
	/**
	 * ファシリティパスを返します
	 * 
	 * @return 重要度
	 * @ejb.interface-method
	 * 
	 */
	public String getFacilityPath() {
		return facilityPath;
	}
	
	/**
	 * ファシリティパスを設定します
	 * 
	 * @param facilityPath
	 * @ejb.interface-method
	 * 
	 */	
	public void setFacilityPath(String facilityPath) {
		this.facilityPath = facilityPath;
	}
	

}
